@@ -425,12 +425,16 @@ class WorkerDataAssertFact(SwaggerView):
             }
 
     def post(self):
+        logger = logging.getLogger(__name__ + "." + self.operationId)
+
         worker_id = request.args.get('worker_id')
         payload_dict = request.json
 
         try:
+            dag_json = json.loads(payload_dict['dag_json'])
             dag = json.loads(payload_dict['dag_json'])
-            data = json.loads(payload_dict['data_json'])
+            data_json = payload_dict['data_json']
+            data = json.loads(data_json)
         except (KeyError, TypeError) as e:
             return Response(
                         f"insufficient data: {e}",
@@ -443,14 +447,22 @@ class WorkerDataAssertFact(SwaggerView):
 
         dag_bucket = "odahub-" + odakb.datalake.form_bucket_name(dag)
         
-        logger.info("storing object %s in dag-motivated bucket: %s", dag[-1], dag_bucket)
+        logger.info("storing object %s size %s Mb in dag-motivated bucket: %s", dag[-1], len(data_json)/1024./1024, dag_bucket)
 
-        bucket = odakb.datalake.store(
-                    dict(dag=dag, data=data),
-                    bucket_name=dag_bucket,
-                )
+        try:
+            open
 
-        assert bucket == dag_bucket
+            bucket = odakb.datalake.store(
+                        dict(dag=dag, data=data),
+                        bucket_name=dag_bucket,
+                    )
+
+            logger.info("returned bucket %s", bucket)
+
+            assert bucket == dag_bucket
+        except Exception as e:
+            logger.error("unable to store bucket %s in datalake: %s", dag_bucket, e)
+            raise
 
         logger.info("succesfully returning!")
 
